import sqlite3
import os
import pkg_resources


def get_db(db_path=None):
    """ returns a connection to the database """
    db_path = db_path or os.path.join(os.environ["HOME"], ".todolist.db")
    conn = sqlite3.connect(db_path)
    conn.row_factory = sqlite3.Row
    return conn


def init_db():
    """ initialize database """
    conn = get_db()
    query = pkg_resources.resource_string(__name__, "init_db.sql")
    conn.executescript(query.decode("utf-8"))


def add_todolist(name, description=None):
    """ add a todolist """
    conn = get_db()
    with conn:
        conn.execute("INSERT INTO todolist (name, description) values (?, ?)", (name, description))


def add_todo(name, todolist_id, description=None, deadline=None, status=0):
    """ add a todo to a todolist """
    conn = get_db()
    query = """
        INSERT INTO todo (name, description, deadline, status, todolist_id) 
        values (?, ?, ?, ?, ?)
    """

    with conn:
        conn.execute(query, (name, description, deadline, status, todolist_id))


def get_all_todolist():
    conn = get_db()
    with conn:
        results = conn.execute("SELECT * FROM todolist")
    return results


def get_todos(todolist_id):
    conn = get_db()
    with conn:
        results = conn.execute("SELECT * FROM todo where todolist_id = ?", (todolist_id,))

    return results

def get_todolist(todolist_id):
    conn = get_db()
    with conn:
        return conn.execute("SELECT * FROM todolist where id = ?", (todolist_id, )).fetchone()



import click
import os

if __name__ == '__main__':
    from hello_todo import db
else:
    from . import db

@click.command()
def todo_lists():
    results = db.get_all_todolist()
    print("%s|%s" % ("name".center(20), "description".center(20)))
    print("%s+%s" % ("-" * 20, "-" * 20))
    for r in results:
        name = r["name"]
        desc = r["description"] or ""
        print("%s|%s" % (name.center(20), desc.center(20)))


@click.command()
@click.option("-l", "--todolist_id", help="Todo list id")
def todo_list(todolist_id):
    todolist_name = db.get_todolist(todolist_id)["name"]
    results = db.get_todos(todolist_id)
    print("** %s **" % todolist_name.upper())
    print(
        "%s|%s|%s|%s"
        % ("status".center(6), "deadline".center(25), "name".center(20), "description".center(20))
    )
    print("%s+%s+%s+%s" % ("-" * 6, "-" * 25, "-" * 20, "-" * 20))

    for r in results:
        status = "x" if r["status"] else " "
        deadline = r["deadline"]
        name = r["name"]
        description = r["description"]
        print(
            "%s|%s|%s|%s"
            % (status.center(6), deadline.center(25), name.center(20), description.center(20))
        )


@click.command()
def init_todo():
    db.init_db()
    click.echo("initialized db at %s", os.path.join(os.environ["HOME"], ".todolist.db"))


@click.command()
@click.option("-n", "--name", help="Todo list name")
@click.option("-d", "--description", default=None, help="Todo list description")
def add_todolist():
    db.add_todolist(name, description)


@click.command()
@click.option("-n", "--name", help="Todo name")
@click.option("-l", "--todolist_id", help="Todo list id")
@click.option("-x", "--deadline", default=None, help="Deadline in format YYYY-MM-dd hh:mm:ss.sss")
@click.option("-d", "--description", default=None, help="Todo description")
def add_todo(name, todolist_id, deadline, description):
    db.add_todo(name, todolist_id, description, deadline)


if __name__ == "__main__":
    todo_list()



# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['hello_todo']

package_data = \
{'': ['*']}

install_requires = \
['click>=7.0,<8.0']

entry_points = \
{'console_scripts': ['add_todo = hello_todo.cli:add_todo',
                     'add_todolist = hello_todo.cli:add_todolist',
                     'init_todos = hello_todo.cli:init_todo',
                     'todos = hello_todo.cli:todo_lists']}

setup_kwargs = {
    'name': 'hello-todo',
    'version': '0.1.3',
    'description': '',
    'long_description': None,
    'author': 'Mathias Ngo',
    'author_email': 'ngo.mathias@gmail.com',
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
}


setup(**setup_kwargs)
